==> commitlint-config-1.1.2.tgz: package/readme.md <==
# @dcm/commitlint-config

[![Commitizen Friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/) [![Version](https://img.shields.io/npm/v/@dcm/commitlint-config.svg)](https://npm.im/@dcm/commitlint-config) [![Weekly Downloads](https://img.shields.io/npm/dw/@dcm/commitlint-config.svg)](https://npm.im/@dcm/commitlint-config)

Shareable commitlint and @commitizen config of @dcmhub.

## Installation

Use npx to install peerdeps automatically or install peerDependencies with npm/yarn manually.

```bash
# Install with npx
$ npx install-peerdeps --dev @dcm/commitlint-config

# Install with NPM
$ npm i -D @commitlint/cli @commitlint/prompt commitizen @dcm/commitlint-config

# Install with yarn
$ yarn add --dev @commitlint/cli @commitlint/prompt commitizen @dcm/commitlint-config
```

## Usage

After installation, you have two methods to use this configuration.

### The first method

Create a `commitlint.config.js` or `.commitlintrc.js` file in your project root, then require this package in the file.

```javascript
module.exports = {
  extends: ['@dcm'], // => @dcm/commitlint-config
};
```

You can also overwrite any rules in this configuration.

```javascript
module.exports = {
  extends: ['@dcm'], // => @dcm/commitlint-config
  rules: {
    'header-max-length': [0, 'always', 72],
  },
};
```

### The second method

If your project have a package.json file, add "commitlint" key in your this file.

```json
{
  "name": "my-cool-project-name",
  "version": "1.0.0",
  "commitlint": {
    "extends": ["@dcm"]
  }
}
```

## With git emoji 🚀

If you want to add git emojis in your commit message, you should extend from emoji version preset.

```javascript
module.exports = {
  extends: ['@dcm/commitlint-config/emoji'],
};
```

## Use with commitizen

Add a "commit" scripts in the package.json, add `@commitlint/prompt` as commitizen's adapter, now you can use `npm run commit` or `yarn commit` to replace the `git commit` command.

```json
{
  "name": "my-cool-project-name",
  "version": "1.0.0",
  "commitlint": {
    "extends": ["@dcm"]
  },
  "scripts": {
    "commit": "git-cz"
  }
}
```

## Use with husky

With husky, you can add a `commit-msg` hook to link message before real commit.

```json
{
  "husky": {
    "hooks": {
      "commit-msg": "commitlint -E HUSKY_GIT_PARAMS"
    }
  }
}
```

## License

MIT

==> commitlint-config-1.2.4.tgz: package/readme.md <==
# @dcm/commitlint-config

[![Commitizen Friendly](https://img.shields.io/badge/commitizen-friendly-brightgreen.svg)](http://commitizen.github.io/cz-cli/) [![Version](https://img.shields.io/npm/v/@dcm/commitlint-config.svg)](https://npm.im/@dcm/commitlint-config) [![Weekly Downloads](https://img.shields.io/npm/dw/@dcm/commitlint-config.svg)](https://npm.im/@dcm/commitlint-config)

Shareable commitlint and @commitizen config of @dcmhub.

## Installation

Use npx to install peerdeps automatically or install peerDependencies with npm/yarn manually.

```bash
# Install with npx
$ npx install-peerdeps --dev @dcm/commitlint-config

# Install with NPM
$ npm i -D @commitlint/cli @commitlint/prompt commitizen @dcm/commitlint-config

# Install with yarn
$ yarn add --dev @commitlint/cli @commitlint/prompt commitizen @dcm/commitlint-config
```

## Usage

After installation, you have two methods to use this configuration.

### The first method

Create a `commitlint.config.js` or `.commitlintrc.js` file in your project root, then require this package in the file.

```javascript
module.exports = {
  extends: ['@dcm'], // => @dcm/commitlint-config
};
```

You can also overwrite any rules in this configuration.

```javascript
module.exports = {
  extends: ['@dcm'], // => @dcm/commitlint-config
  rules: {
    'header-max-length': [0, 'always', 72],
  },
};
```

### The second method

If your project have a package.json file, add "commitlint" key in your this file.

```json
{
  "name": "my-cool-project-name",
  "version": "1.0.0",
  "commitlint": {
    "extends": ["@dcm"]
  }
}
```

## With lerna

If you want to use with lerna monorepo, you should extend from `lerna` or `lerna-emoji` version preset.

```javascript
module.exports = {
  extends: ['@dcm/commitlint-config/lerna'],
  // extends: ['@dcm/commitlint-config/lerna-emoji'],
};
```

## With git emoji 🚀

If you want to add gitmojis in your commit message, you should extend from emoji version preset.

```javascript
module.exports = {
  extends: ['@dcm/commitlint-config/emoji'],
};
```

## Use with commitizen

Add a "commit" scripts in the package.json, add `@commitlint/prompt` as commitizen's adapter, now you can use `npm run commit` or `yarn commit` to replace the `git commit` command.

```json
{
  "name": "my-cool-project-name",
  "version": "1.0.0",
  "commitlint": {
    "extends": ["@dcm"]
  },
  "scripts": {
    "commit": "git-cz"
  }
}
```

## Use with husky

With husky, you can add a `commit-msg` hook to link message before real commit.

```json
{
  "husky": {
    "hooks": {
      "commit-msg": "commitlint -E HUSKY_GIT_PARAMS"
    }
  }
}
```

## License

MIT
